@@ -1,21 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2013 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
- *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
- *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
- *************************************************************************************/
-
+/*
+ *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
+ */
 #include "createaccountjob.h"
 
 #include "kaccountsuiplugin.h"
@@ -107,6 +94,7 @@ void CreateAccountJob::loadPluginAndShowDialog(const QString &pluginName)
 
     connect(ui, &KAccountsUiPlugin::success, this, &CreateAccountJob::pluginFinished, Qt::UniqueConnection);
     connect(ui, &KAccountsUiPlugin::error, this, &CreateAccountJob::pluginError, Qt::UniqueConnection);
+    connect(ui, &KAccountsUiPlugin::canceled, this, &CreateAccountJob::pluginCancelled, Qt::UniqueConnection);
 
     ui->setProviderName(m_providerName);
     ui->init(KAccountsUiPlugin::NewAccountDialog);
@@ -155,6 +143,14 @@ void CreateAccountJob::pluginError(const QString &error)
     emitResult();
 }
 
+void CreateAccountJob::pluginCancelled()
+{
+    setError(KJob::KilledJobError);
+    setErrorText(i18n("Cancelled by user"));
+
+    emitResult();
+}
+
 void CreateAccountJob::sessionResponse(const SignOn::SessionData &/*data*/)
 {
     qDebug() << "Received session response";
