@@ -1,22 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2013 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2 of the License, or (at your option) any later version.                 *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Library General Public License for more details.                                 *
- *                                                                                   *
- *  You should have received a copy of the GNU Library General Public License        *
- *  along with this library; see the file COPYING.LIB.  If not, write to             *
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,             *
- *  Boston, MA 02110-1301, USA.                                                      *
- *************************************************************************************/
-
+/*
+ *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 #include "getcredentialsjob.h"
 #include "core.h"
 
@@ -93,13 +79,13 @@ void GetCredentialsJob::Private::getCredentials()
         return;
     }
 
-    QObject::connect(authSession.data(), &SignOn::AuthSession::response,
+    QObject::connect(authSession.data(), &SignOn::AuthSession::response, q,
             [this](const SignOn::SessionData &data) {
                 sessionData = data;
                 q->emitResult();
             });
 
-    QObject::connect(authSession.data(), &SignOn::AuthSession::error,
+    QObject::connect(authSession.data(), &SignOn::AuthSession::error, q,
             [this](const SignOn::Error &error) {
                 qDebug() << error.message();
                 q->setError(KJob::UserDefinedError);
