@@ -1,21 +1,7 @@
 /*
- * Copyright 2014  Martin Klapetek <mklapetek@kde.org>
+ * SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  *
  */
 
@@ -97,6 +83,11 @@ Q_SIGNALS:
      * @param errorString The error that has occurred
      */
     void error(const QString &errorString);
+
+    /**
+     * Emitted when the user cancels the account creation
+     */
+    void canceled();
 };
 
 Q_DECLARE_INTERFACE(KAccountsUiPlugin, "org.kde.kaccounts.UiPlugin")
