@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
- *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
- *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "createnetattachjob.h"
 
@@ -82,7 +70,7 @@ void CreateNetAttachJob::getRealm()
     QUrl url;
     url.setHost(m_host);
     url.setUserName(m_username);
-    url.setScheme(QStringLiteral("webdav"));
+    url.setScheme(QStringLiteral("webdavs"));
     url.setPath(m_path);
 
     if (!m_realm.isEmpty()) {
@@ -120,16 +108,15 @@ void CreateNetAttachJob::createDesktopFile(const QUrl &url)
 {
     qDebug();
 
-    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    path.append(QStringLiteral("/remoteview/"));
+    const QString folderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/remoteview/");
 
-    QDir saveDir(path);
+    QDir saveDir(folderPath);
     if (!saveDir.exists()) {
-        if (!saveDir.mkpath(path)) {
-            qWarning() << "Directory" << path << "for storage couldn't be created!";
+        if (!saveDir.mkpath(folderPath)) {
+            qWarning() << "Directory" << folderPath << "for storage couldn't be created!";
         }
     }
-    path += m_uniqueId + QStringLiteral(".desktop");
+    const QString path = folderPath + m_uniqueId + QStringLiteral(".desktop");
 
     qDebug() << "Creating knetAttach place";
     qDebug() << path;
